cairo_
annotations
0.2.0
Module annotations
Module Items
Modules
Enums
Traits
In crate cairo_
annotations
cairo_annotations
Module
annotations
Modules

coverage
profiler
Enums

Annotations
Error
Enum representing the possible errors that can occur when trying to create an annotation from sierra debug information.
Traits

TryFrom
Debug
Info