Structs
- A location of Sierra statement.
- The mapping from sierra statement index to stack of a locations in Cairo code which caused the statement to be generated. And all functions that were inlined or generated along the way up to the first non-inlined function from the original code.
- A location in a Cairo source file.
- A span in a Cairo source file.
- A full path to a Cairo source file.
Enums
- Versioned representation of Coverage Annotations.