pub struct CoverageAnnotationsV1 {
pub statements_code_locations: HashMap<StatementIdx, Vec<CodeLocation>>,
}Expand description
The mapping from sierra statement index to stack of a locations in Cairo code which caused the statement to be generated. And all functions that were inlined or generated along the way up to the first non-inlined function from the original code.
The vector represents the stack from the least meaningful elements.
Introduced in Scarb 2.8.0.
Needs unstable-add-statements-code-locations-debug-info = true
under [profile.dev.cairo] in the Scarb config to be generated.
Fields
statements_code_locations: HashMap<StatementIdx, Vec<CodeLocation>>Trait Implementations
Sourceimpl Clone for CoverageAnnotationsV1
impl Clone for CoverageAnnotationsV1
Sourcefn clone(&self) -> CoverageAnnotationsV1
fn clone(&self) -> CoverageAnnotationsV1
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CoverageAnnotationsV1
impl Debug for CoverageAnnotationsV1
Sourceimpl<'de> Deserialize<'de> for CoverageAnnotationsV1
impl<'de> Deserialize<'de> for CoverageAnnotationsV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for CoverageAnnotationsV1
impl PartialEq for CoverageAnnotationsV1
Sourceimpl Serialize for CoverageAnnotationsV1
impl Serialize for CoverageAnnotationsV1
impl Eq for CoverageAnnotationsV1
impl StructuralPartialEq for CoverageAnnotationsV1