pub struct SourceCodeSpan {
pub start: SourceCodeLocation,
pub end: SourceCodeLocation,
}Expand description
A span in a Cairo source file.
Fields
start: SourceCodeLocationBeginning of the text span in the Cairo source file.
end: SourceCodeLocationEnd of the text span in the Cairo source file. Currently, always the same as start.