pub enum AnnotationsError {
MissingNamespace(String),
DeserializationError(Error),
}Expand description
Enum representing the possible errors that can occur when trying to create an annotation from sierra debug information.
Variants
MissingNamespace(String)
Error indicating that the namespace is missing from the annotations.
DeserializationError(Error)
Error indicating that the deserialization of the annotation failed.