Structs
- The fully qualified Cairo path of the Cairo function.
- The mapping from sierra statement index to stack a fully qualified Cairo paths of the Cairo functions which caused the statement to be generated. And all functions that were inlined or generated along the way up to the first non-inlined function from the original code.
Enums
- Versioned representation of Profiler Annotations.