pub struct ProfilerAnnotationsV1 {
pub statements_functions: HashMap<StatementIdx, Vec<FunctionName>>,
}Expand description
The mapping from sierra statement index to stack a fully qualified Cairo paths of the Cairo functions which caused the statement to be generated. And all functions that were inlined or generated along the way up to the first non-inlined function from the original code.
The vector represents the stack from the least meaningful elements.
Introduced in Scarb 2.7.0.
Needs unstable-add-statements-functions-debug-info = true
under [profile.dev.cairo] in the Scarb config to be generated.
Fields
statements_functions: HashMap<StatementIdx, Vec<FunctionName>>Trait Implementations
Sourceimpl Clone for ProfilerAnnotationsV1
impl Clone for ProfilerAnnotationsV1
Sourcefn clone(&self) -> ProfilerAnnotationsV1
fn clone(&self) -> ProfilerAnnotationsV1
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProfilerAnnotationsV1
impl Debug for ProfilerAnnotationsV1
Sourceimpl<'de> Deserialize<'de> for ProfilerAnnotationsV1
impl<'de> Deserialize<'de> for ProfilerAnnotationsV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ProfilerAnnotationsV1
impl PartialEq for ProfilerAnnotationsV1
Sourceimpl Serialize for ProfilerAnnotationsV1
impl Serialize for ProfilerAnnotationsV1
impl Eq for ProfilerAnnotationsV1
impl StructuralPartialEq for ProfilerAnnotationsV1