cairo_annotations::annotations

Trait TryFromDebugInfo

pub trait TryFromDebugInfo: Sized {
    type Error: Error;

    // Required method
    fn try_from_debug_info(
        sierra_debug_info: &DebugInfo,
    ) -> Result<Self, Self::Error>;
}

Required Associated Types

Required Methods

fn try_from_debug_info( sierra_debug_info: &DebugInfo, ) -> Result<Self, Self::Error>

Attempt to create an instance of the implementing type from the provided sierra DebugInfo.

Errors

This function will return an error if the conversion from DebugInfo to the implementing type fails.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors