pub enum MappingResult {
SierraStatementIdx(StatementIdx),
Header,
PcOutOfFunctionArea,
}Expand description
Enum to represent the result of mapping a pc to a sierra statement id.
Variants
SierraStatementIdx(StatementIdx)
The pc was successfully mapped to a sierra statement id.
Header
The pc was not mapped to a sierra statement id because it was in the header of the program.
PcOutOfFunctionArea
The pc was not mapped to a sierra statement id because it was outside the function area.