Structs
- Struct needed for function level profiling.
- Tree structure representing trace of a call. This struct should be serialized and used as an input to cairo-profiler.
Enums
- Enum representing node of a trace of a call.
- Versioned representation of
CallTrace.